#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .fluid_child_1 import fluid_child


class fluid(NamedObject[fluid_child], _NonCreatableNamedObjectMixin[fluid_child]):
    """
    'fluid' child.
    """

    fluent_name = "fluid"

    child_object_type: fluid_child = fluid_child
    """
    child_object_type of fluid.
    """
    return_type = "<object object at 0x7f5bb22b4ea0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .fixed_cycle_parameters_1 import fixed_cycle_parameters as fixed_cycle_parameters_cls
from .coarsening_parameters_1 import coarsening_parameters as coarsening_parameters_cls
from .smoother_type_1 import smoother_type as smoother_type_cls

class coupled_parameters(Group):
    """
    'coupled_parameters' child.
    """

    fluent_name = "coupled-parameters"

    child_names = \
        ['fixed_cycle_parameters', 'coarsening_parameters', 'smoother_type']

    _child_classes = dict(
        fixed_cycle_parameters=fixed_cycle_parameters_cls,
        coarsening_parameters=coarsening_parameters_cls,
        smoother_type=smoother_type_cls,
    )

    return_type = "<object object at 0x7f5bb1466df0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .pressure_gradient_force import pressure_gradient_force as pressure_gradient_force_cls
from .virtual_mass_force import virtual_mass_force as virtual_mass_force_cls
from .volume_displacement_1 import volume_displacement as volume_displacement_cls
from .wall_film import wall_film as wall_film_cls

class physical_models(Group):
    """
    Main menu to enable the required physical submodels for the discrete phase model.
    """

    fluent_name = "physical-models"

    child_names = \
        ['pressure_gradient_force', 'virtual_mass_force',
         'volume_displacement', 'wall_film']

    _child_classes = dict(
        pressure_gradient_force=pressure_gradient_force_cls,
        virtual_mass_force=virtual_mass_force_cls,
        volume_displacement=volume_displacement_cls,
        wall_film=wall_film_cls,
    )

    return_type = "<object object at 0x7fc41c4f5600>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .density_2 import density as density_cls
from .viscosity_1 import viscosity as viscosity_cls
from .specific_heat_2 import specific_heat as specific_heat_cls
from .thermal_conductivity_2 import thermal_conductivity as thermal_conductivity_cls
from .premix_laminar_speed import premix_laminar_speed as premix_laminar_speed_cls
from .premix_laminar_thickness import premix_laminar_thickness as premix_laminar_thickness_cls
from .premix_unburnt_temp_1 import premix_unburnt_temp as premix_unburnt_temp_cls
from .premix_unburnt_cp import premix_unburnt_cp as premix_unburnt_cp_cls
from .premix_unburnt_density_1 import premix_unburnt_density as premix_unburnt_density_cls
from .premix_heat_trans_coeff_1 import premix_heat_trans_coeff as premix_heat_trans_coeff_cls
from .premix_critical_strain import premix_critical_strain as premix_critical_strain_cls
from .therm_exp_coeff import therm_exp_coeff as therm_exp_coeff_cls
from .absorption_coefficient_1 import absorption_coefficient as absorption_coefficient_cls
from .scattering_coefficient import scattering_coefficient as scattering_coefficient_cls
from .scattering_phase_function import scattering_phase_function as scattering_phase_function_cls
from .refractive_index import refractive_index as refractive_index_cls
from .mass_diffusivity_1 import mass_diffusivity as mass_diffusivity_cls
from .species import species as species_cls
from .reactions import reactions as reactions_cls
from .reaction_mechs import reaction_mechs as reaction_mechs_cls
from .uds_diffusivity import uds_diffusivity as uds_diffusivity_cls
from .thermal_diffusivity import thermal_diffusivity as thermal_diffusivity_cls
from .tmelt import tmelt as tmelt_cls
from .melting_heat import melting_heat as melting_heat_cls
from .eutectic_temp import eutectic_temp as eutectic_temp_cls
from .speed_of_sound import speed_of_sound as speed_of_sound_cls
from .critical_temperature import critical_temperature as critical_temperature_cls
from .critical_pressure import critical_pressure as critical_pressure_cls
from .critical_volume import critical_volume as critical_volume_cls
from .acentric_factor import acentric_factor as acentric_factor_cls
from .electric_conductivity import electric_conductivity as electric_conductivity_cls
from .dual_electric_conductivity import dual_electric_conductivity as dual_electric_conductivity_cls
from .lithium_diffusivity import lithium_diffusivity as lithium_diffusivity_cls
from .collision_cross_section import collision_cross_section as collision_cross_section_cls
from .mixture_species import mixture_species as mixture_species_cls

class mixture_child(Group):
    """
    'child_object_type' of mixture.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['density', 'viscosity', 'specific_heat', 'thermal_conductivity',
         'premix_laminar_speed', 'premix_laminar_thickness',
         'premix_unburnt_temp', 'premix_unburnt_cp', 'premix_unburnt_density',
         'premix_heat_trans_coeff', 'premix_critical_strain',
         'therm_exp_coeff', 'absorption_coefficient',
         'scattering_coefficient', 'scattering_phase_function',
         'refractive_index', 'mass_diffusivity', 'species', 'reactions',
         'reaction_mechs', 'uds_diffusivity', 'thermal_diffusivity', 'tmelt',
         'melting_heat', 'eutectic_temp', 'speed_of_sound',
         'critical_temperature', 'critical_pressure', 'critical_volume',
         'acentric_factor', 'electric_conductivity',
         'dual_electric_conductivity', 'lithium_diffusivity',
         'collision_cross_section', 'mixture_species']

    _child_classes = dict(
        density=density_cls,
        viscosity=viscosity_cls,
        specific_heat=specific_heat_cls,
        thermal_conductivity=thermal_conductivity_cls,
        premix_laminar_speed=premix_laminar_speed_cls,
        premix_laminar_thickness=premix_laminar_thickness_cls,
        premix_unburnt_temp=premix_unburnt_temp_cls,
        premix_unburnt_cp=premix_unburnt_cp_cls,
        premix_unburnt_density=premix_unburnt_density_cls,
        premix_heat_trans_coeff=premix_heat_trans_coeff_cls,
        premix_critical_strain=premix_critical_strain_cls,
        therm_exp_coeff=therm_exp_coeff_cls,
        absorption_coefficient=absorption_coefficient_cls,
        scattering_coefficient=scattering_coefficient_cls,
        scattering_phase_function=scattering_phase_function_cls,
        refractive_index=refractive_index_cls,
        mass_diffusivity=mass_diffusivity_cls,
        species=species_cls,
        reactions=reactions_cls,
        reaction_mechs=reaction_mechs_cls,
        uds_diffusivity=uds_diffusivity_cls,
        thermal_diffusivity=thermal_diffusivity_cls,
        tmelt=tmelt_cls,
        melting_heat=melting_heat_cls,
        eutectic_temp=eutectic_temp_cls,
        speed_of_sound=speed_of_sound_cls,
        critical_temperature=critical_temperature_cls,
        critical_pressure=critical_pressure_cls,
        critical_volume=critical_volume_cls,
        acentric_factor=acentric_factor_cls,
        electric_conductivity=electric_conductivity_cls,
        dual_electric_conductivity=dual_electric_conductivity_cls,
        lithium_diffusivity=lithium_diffusivity_cls,
        collision_cross_section=collision_cross_section_cls,
        mixture_species=mixture_species_cls,
    )

    return_type = "<object object at 0x7f5bb1e70ef0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .method_3 import method as method_cls
from .samp_time_period import samp_time_period as samp_time_period_cls
from .samp_time_steps import samp_time_steps as samp_time_steps_cls
from .avg_time_period import avg_time_period as avg_time_period_cls
from .avg_time_steps import avg_time_steps as avg_time_steps_cls

class statistics_controls(Command):
    """
    'statistics_controls' command.
    
    Parameters
    ----------
        method : int
            'method' child.
        samp_time_period : real
            'samp_time_period' child.
        samp_time_steps : int
            'samp_time_steps' child.
        avg_time_period : real
            'avg_time_period' child.
        avg_time_steps : int
            'avg_time_steps' child.
    
    """

    fluent_name = "statistics-controls"

    argument_names = \
        ['method', 'samp_time_period', 'samp_time_steps', 'avg_time_period',
         'avg_time_steps']

    _child_classes = dict(
        method=method_cls,
        samp_time_period=samp_time_period_cls,
        samp_time_steps=samp_time_steps_cls,
        avg_time_period=avg_time_period_cls,
        avg_time_steps=avg_time_steps_cls,
    )

    return_type = "<object object at 0x7fc41c4f5f80>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .models import models as models_cls
from .vaporization_pressure import vaporization_pressure as vaporization_pressure_cls
from .non_condensable_gas import non_condensable_gas as non_condensable_gas_cls
from .liquid_surface_tension import liquid_surface_tension as liquid_surface_tension_cls
from .bubble_number_density import bubble_number_density as bubble_number_density_cls
from .number_of_phases import number_of_phases as number_of_phases_cls
from .number_of_eulerian_discrete_phases import number_of_eulerian_discrete_phases as number_of_eulerian_discrete_phases_cls

class multiphase(Group):
    fluent_name = ...
    child_names = ...
    models: models_cls = ...
    vaporization_pressure: vaporization_pressure_cls = ...
    non_condensable_gas: non_condensable_gas_cls = ...
    liquid_surface_tension: liquid_surface_tension_cls = ...
    bubble_number_density: bubble_number_density_cls = ...
    number_of_phases: number_of_phases_cls = ...
    number_of_eulerian_discrete_phases: number_of_eulerian_discrete_phases_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .geom_disable import geom_disable as geom_disable_cls
from .geom_dir_spec import geom_dir_spec as geom_dir_spec_cls
from .geom_dir_x import geom_dir_x as geom_dir_x_cls
from .geom_dir_y import geom_dir_y as geom_dir_y_cls
from .geom_dir_z import geom_dir_z as geom_dir_z_cls
from .geom_levels import geom_levels as geom_levels_cls
from .geom_bgthread import geom_bgthread as geom_bgthread_cls
from .porous_jump_turb_wall_treatment import porous_jump_turb_wall_treatment as porous_jump_turb_wall_treatment_cls
from .dir import dir as dir_cls
from .average_dp import average_dp as average_dp_cls
from .c import c as c_cls
from .limit_range import limit_range as limit_range_cls
from .v_min import v_min as v_min_cls
from .v_max import v_max as v_max_cls
from .strength import strength as strength_cls
from .profile_dp import profile_dp as profile_dp_cls
from .dp_profile import dp_profile as dp_profile_cls
from .swirl_model import swirl_model as swirl_model_cls
from .fan_vr import fan_vr as fan_vr_cls
from .fr import fr as fr_cls
from .hub import hub as hub_cls
from .axis_origin_component_1 import axis_origin_component as axis_origin_component_cls
from .axis_direction_component_1 import axis_direction_component as axis_direction_component_cls
from .profile_vt import profile_vt as profile_vt_cls
from .vt_profile import vt_profile as vt_profile_cls
from .profile_vr import profile_vr as profile_vr_cls
from .vr_profile import vr_profile as vr_profile_cls
from .swirl_factor import swirl_factor as swirl_factor_cls
from .dpm_bc_type import dpm_bc_type as dpm_bc_type_cls
from .dpm_bc_collision_partner import dpm_bc_collision_partner as dpm_bc_collision_partner_cls
from .reinj_inj import reinj_inj as reinj_inj_cls
from .dpm_bc_udf import dpm_bc_udf as dpm_bc_udf_cls
from .new_fan_definition import new_fan_definition as new_fan_definition_cls

class phase_child(Group):
    """
    'child_object_type' of phase.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['geom_disable', 'geom_dir_spec', 'geom_dir_x', 'geom_dir_y',
         'geom_dir_z', 'geom_levels', 'geom_bgthread',
         'porous_jump_turb_wall_treatment', 'dir', 'average_dp', 'c',
         'limit_range', 'v_min', 'v_max', 'strength', 'profile_dp',
         'dp_profile', 'swirl_model', 'fan_vr', 'fr', 'hub',
         'axis_origin_component', 'axis_direction_component', 'profile_vt',
         'vt_profile', 'profile_vr', 'vr_profile', 'swirl_factor',
         'dpm_bc_type', 'dpm_bc_collision_partner', 'reinj_inj', 'dpm_bc_udf',
         'new_fan_definition']

    _child_classes = dict(
        geom_disable=geom_disable_cls,
        geom_dir_spec=geom_dir_spec_cls,
        geom_dir_x=geom_dir_x_cls,
        geom_dir_y=geom_dir_y_cls,
        geom_dir_z=geom_dir_z_cls,
        geom_levels=geom_levels_cls,
        geom_bgthread=geom_bgthread_cls,
        porous_jump_turb_wall_treatment=porous_jump_turb_wall_treatment_cls,
        dir=dir_cls,
        average_dp=average_dp_cls,
        c=c_cls,
        limit_range=limit_range_cls,
        v_min=v_min_cls,
        v_max=v_max_cls,
        strength=strength_cls,
        profile_dp=profile_dp_cls,
        dp_profile=dp_profile_cls,
        swirl_model=swirl_model_cls,
        fan_vr=fan_vr_cls,
        fr=fr_cls,
        hub=hub_cls,
        axis_origin_component=axis_origin_component_cls,
        axis_direction_component=axis_direction_component_cls,
        profile_vt=profile_vt_cls,
        vt_profile=vt_profile_cls,
        profile_vr=profile_vr_cls,
        vr_profile=vr_profile_cls,
        swirl_factor=swirl_factor_cls,
        dpm_bc_type=dpm_bc_type_cls,
        dpm_bc_collision_partner=dpm_bc_collision_partner_cls,
        reinj_inj=reinj_inj_cls,
        dpm_bc_udf=dpm_bc_udf_cls,
        new_fan_definition=new_fan_definition_cls,
    )

    return_type = "<object object at 0x7ff7041c9bd0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .option import option as option_cls
from .min_max import min_max as min_max_cls
from .in_range import in_range as in_range_cls
from .except_in_range import except_in_range as except_in_range_cls
from .top_value_cells import top_value_cells as top_value_cells_cls
from .low_value_cells import low_value_cells as low_value_cells_cls
from .less_than import less_than as less_than_cls
from .more_than import more_than as more_than_cls
from .between_std_dev import between_std_dev as between_std_dev_cls
from .outside_std_dev import outside_std_dev as outside_std_dev_cls
from .less_than_std_dev import less_than_std_dev as less_than_std_dev_cls
from .more_than_std_dev import more_than_std_dev as more_than_std_dev_cls

class option(Group):
    """
    'option' child.
    """

    fluent_name = "option"

    child_names = \
        ['option', 'min_max', 'in_range', 'except_in_range',
         'top_value_cells', 'low_value_cells', 'less_than', 'more_than',
         'between_std_dev', 'outside_std_dev', 'less_than_std_dev',
         'more_than_std_dev']

    _child_classes = dict(
        option=option_cls,
        min_max=min_max_cls,
        in_range=in_range_cls,
        except_in_range=except_in_range_cls,
        top_value_cells=top_value_cells_cls,
        low_value_cells=low_value_cells_cls,
        less_than=less_than_cls,
        more_than=more_than_cls,
        between_std_dev=between_std_dev_cls,
        outside_std_dev=outside_std_dev_cls,
        less_than_std_dev=less_than_std_dev_cls,
        more_than_std_dev=more_than_std_dev_cls,
    )

    return_type = "<object object at 0x7fc3bc2a7180>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .name_1 import name as name_cls
from .uid import uid as uid_cls
from .options_6 import options as options_cls
from .range import range as range_cls
from .style_attribute import style_attribute as style_attribute_cls
from .accuracy_control_1 import accuracy_control as accuracy_control_cls
from .plot_1 import plot as plot_cls
from .step import step as step_cls
from .skip import skip as skip_cls
from .coarsen import coarsen as coarsen_cls
from .onzone import onzone as onzone_cls
from .onphysics import onphysics as onphysics_cls
from .field import field as field_cls
from .surfaces_list import surfaces_list as surfaces_list_cls
from .velocity_domain import velocity_domain as velocity_domain_cls
from .color_map import color_map as color_map_cls
from .draw_mesh import draw_mesh as draw_mesh_cls
from .mesh_object import mesh_object as mesh_object_cls
from .display_state_name import display_state_name as display_state_name_cls
from .physics import physics as physics_cls
from .geometry_3 import geometry as geometry_cls
from .surfaces import surfaces as surfaces_cls
from .axes import axes as axes_cls
from .curves import curves as curves_cls
from .display_2 import display as display_cls

class pathline_child(Group):
    """
    'child_object_type' of pathline.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'uid', 'options', 'range', 'style_attribute',
         'accuracy_control', 'plot', 'step', 'skip', 'coarsen', 'onzone',
         'onphysics', 'field', 'surfaces_list', 'velocity_domain',
         'color_map', 'draw_mesh', 'mesh_object', 'display_state_name',
         'physics', 'geometry', 'surfaces', 'axes', 'curves']

    command_names = \
        ['display']

    _child_classes = dict(
        name=name_cls,
        uid=uid_cls,
        options=options_cls,
        range=range_cls,
        style_attribute=style_attribute_cls,
        accuracy_control=accuracy_control_cls,
        plot=plot_cls,
        step=step_cls,
        skip=skip_cls,
        coarsen=coarsen_cls,
        onzone=onzone_cls,
        onphysics=onphysics_cls,
        field=field_cls,
        surfaces_list=surfaces_list_cls,
        velocity_domain=velocity_domain_cls,
        color_map=color_map_cls,
        draw_mesh=draw_mesh_cls,
        mesh_object=mesh_object_cls,
        display_state_name=display_state_name_cls,
        physics=physics_cls,
        geometry=geometry_cls,
        surfaces=surfaces_cls,
        axes=axes_cls,
        curves=curves_cls,
        display=display_cls,
    )

    return_type = "<object object at 0x7f5bb1254790>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .enable_solid_time_step import enable_solid_time_step as enable_solid_time_step_cls
from .choose_auto_time_stepping import choose_auto_time_stepping as choose_auto_time_stepping_cls
from .time_step_size_1 import time_step_size as time_step_size_cls

class solid_time_step_size(Group):
    fluent_name = ...
    child_names = ...
    enable_solid_time_step: enable_solid_time_step_cls = ...
    choose_auto_time_stepping: choose_auto_time_stepping_cls = ...
    time_step_size: time_step_size_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .state_name import state_name as state_name_cls

class restore_state(Command):
    """
    Apply a display state to the active window.
    
    Parameters
    ----------
        state_name : str
            'state_name' child.
    
    """

    fluent_name = "restore-state"

    argument_names = \
        ['state_name']

    _child_classes = dict(
        state_name=state_name_cls,
    )

    return_type = "<object object at 0x7ff703071010>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .smoothed_density_stabilization_method import smoothed_density_stabilization_method as smoothed_density_stabilization_method_cls
from .num_of_density_smoothing import num_of_density_smoothing as num_of_density_smoothing_cls
from .false_time_step_linearization import false_time_step_linearization as false_time_step_linearization_cls
from .auto_dt_advanced_controls import auto_dt_advanced_controls as auto_dt_advanced_controls_cls

class pseudo_transient(Group):
    fluent_name = ...
    child_names = ...
    smoothed_density_stabilization_method: smoothed_density_stabilization_method_cls = ...
    num_of_density_smoothing: num_of_density_smoothing_cls = ...
    false_time_step_linearization: false_time_step_linearization_cls = ...
    auto_dt_advanced_controls: auto_dt_advanced_controls_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .general_settings_1 import general_settings as general_settings_cls
from .turbulent_setting import turbulent_setting as turbulent_setting_cls
from .species_setting import species_setting as species_setting_cls

class hybrid_init_options(Group):
    """
    Enter the settings for hybrid initialization method.
    """

    fluent_name = "hybrid-init-options"

    child_names = \
        ['general_settings', 'turbulent_setting', 'species_setting']

    _child_classes = dict(
        general_settings=general_settings_cls,
        turbulent_setting=turbulent_setting_cls,
        species_setting=species_setting_cls,
    )

    return_type = "<object object at 0x7fc3bc2a7970>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .acoustics_wave_eqn_controls import acoustics_wave_eqn_controls as acoustics_wave_eqn_controls_cls
from .advanced import advanced as advanced_cls
from .contact_solution_controls import contact_solution_controls as contact_solution_controls_cls
from .courant_number import courant_number as courant_number_cls
from .equations import equations as equations_cls
from .limits import limits as limits_cls
from .p_v_controls import p_v_controls as p_v_controls_cls
from .relaxation_factor_1 import relaxation_factor as relaxation_factor_cls
from .set_controls_to_default import set_controls_to_default as set_controls_to_default_cls
from .under_relaxation import under_relaxation as under_relaxation_cls
from .pseudo_time_explicit_relaxation_factor import pseudo_time_explicit_relaxation_factor as pseudo_time_explicit_relaxation_factor_cls
from .pseudo_time_method_local_time_step import pseudo_time_method_local_time_step as pseudo_time_method_local_time_step_cls

class controls(Group):
    """
    'controls' child.
    """

    fluent_name = "controls"

    child_names = \
        ['acoustics_wave_eqn_controls', 'advanced',
         'contact_solution_controls', 'courant_number', 'equations', 'limits',
         'p_v_controls', 'relaxation_factor', 'set_controls_to_default',
         'under_relaxation', 'pseudo_time_explicit_relaxation_factor',
         'pseudo_time_method_local_time_step']

    _child_classes = dict(
        acoustics_wave_eqn_controls=acoustics_wave_eqn_controls_cls,
        advanced=advanced_cls,
        contact_solution_controls=contact_solution_controls_cls,
        courant_number=courant_number_cls,
        equations=equations_cls,
        limits=limits_cls,
        p_v_controls=p_v_controls_cls,
        relaxation_factor=relaxation_factor_cls,
        set_controls_to_default=set_controls_to_default_cls,
        under_relaxation=under_relaxation_cls,
        pseudo_time_explicit_relaxation_factor=pseudo_time_explicit_relaxation_factor_cls,
        pseudo_time_method_local_time_step=pseudo_time_method_local_time_step_cls,
    )

    return_type = "<object object at 0x7f5bb1467850>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .verbosity_8 import verbosity as verbosity_cls
from .time_step_method_1 import time_step_method as time_step_method_cls

class pseudo_time_settings(Group):
    fluent_name = ...
    child_names = ...
    verbosity: verbosity_cls = ...
    time_step_method: time_step_method_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .method_4 import method as method_cls
from .value_1 import value as value_cls
from .user_defined import user_defined as user_defined_cls

class anode_sigma(Group):
    """
    'anode_sigma' child.
    """

    fluent_name = "anode-sigma"

    child_names = \
        ['method', 'value', 'user_defined']

    _child_classes = dict(
        method=method_cls,
        value=value_cls,
        user_defined=user_defined_cls,
    )

    return_type = "<object object at 0x7fa445e98320>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .pole import pole as pole_cls
from .amplitude import amplitude as amplitude_cls

class impedance_1_child(Group):
    """
    'child_object_type' of impedance_1.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['pole', 'amplitude']

    _child_classes = dict(
        pole=pole_cls,
        amplitude=amplitude_cls,
    )

    return_type = "<object object at 0x7ff7042eddd0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .edc_choice import edc_choice as edc_choice_cls
from .edc_constant_coefficient_options import edc_constant_coefficient_options as edc_constant_coefficient_options_cls
from .edc_pasr_model_options import edc_pasr_model_options as edc_pasr_model_options_cls
from .user_defined_edc_scales import user_defined_edc_scales as user_defined_edc_scales_cls

class edc_model_options(Group):
    """
    'edc_model_options' child.
    """

    fluent_name = "edc-model-options"

    child_names = \
        ['edc_choice', 'edc_constant_coefficient_options',
         'edc_pasr_model_options', 'user_defined_edc_scales']

    _child_classes = dict(
        edc_choice=edc_choice_cls,
        edc_constant_coefficient_options=edc_constant_coefficient_options_cls,
        edc_pasr_model_options=edc_pasr_model_options_cls,
        user_defined_edc_scales=user_defined_edc_scales_cls,
    )

    return_type = "<object object at 0x7fc41c4f41c0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .low_order_rhie_chow import low_order_rhie_chow as low_order_rhie_chow_cls

class rhie_chow_flux(Group):
    """
    'rhie_chow_flux' child.
    """

    fluent_name = "rhie-chow-flux"

    child_names = \
        ['low_order_rhie_chow']

    _child_classes = dict(
        low_order_rhie_chow=low_order_rhie_chow_cls,
    )

    return_type = "<object object at 0x7f5bb1467e70>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .fps import fps as fps_cls
from .format_2 import format as format_cls
from .quality_2 import quality as quality_cls
from .name_4 import name as name_cls
from .use_original_resolution import use_original_resolution as use_original_resolution_cls
from .scale_4 import scale as scale_cls
from .set_standard_resolution import set_standard_resolution as set_standard_resolution_cls
from .width_2 import width as width_cls
from .height_2 import height as height_cls
from .advance_quality import advance_quality as advance_quality_cls

class video(Group):
    """
    'video' child.
    """

    fluent_name = "video"

    child_names = \
        ['fps', 'format', 'quality', 'name', 'use_original_resolution',
         'scale', 'set_standard_resolution', 'width', 'height',
         'advance_quality']

    _child_classes = dict(
        fps=fps_cls,
        format=format_cls,
        quality=quality_cls,
        name=name_cls,
        use_original_resolution=use_original_resolution_cls,
        scale=scale_cls,
        set_standard_resolution=set_standard_resolution_cls,
        width=width_cls,
        height=height_cls,
        advance_quality=advance_quality_cls,
    )

    return_type = "<object object at 0x7fc3a7f85fe0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .all import all as all_cls
from .auto import auto as auto_cls
from .use_local_edge_length_factor import use_local_edge_length_factor as use_local_edge_length_factor_cls
from .tolerance1 import tolerance1 as tolerance1_cls
from .tolerance2 import tolerance2 as tolerance2_cls

class convert_to_mapped_interface(Command):
    fluent_name = ...
    argument_names = ...
    all: all_cls = ...
    auto: auto_cls = ...
    use_local_edge_length_factor: use_local_edge_length_factor_cls = ...
    tolerance1: tolerance1_cls = ...
    tolerance2: tolerance2_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .model import model as model_cls
from .options import options as options_cls
from .spalart_allmaras_production import spalart_allmaras_production as spalart_allmaras_production_cls
from .k_epsilon_model import k_epsilon_model as k_epsilon_model_cls
from .k_omega_model import k_omega_model as k_omega_model_cls
from .k_omega_options import k_omega_options as k_omega_options_cls
from .rng_options import rng_options as rng_options_cls
from .near_wall_treatment import near_wall_treatment as near_wall_treatment_cls
from .transition_sst_options import transition_sst_options as transition_sst_options_cls
from .reynolds_stress_model import reynolds_stress_model as reynolds_stress_model_cls
from .subgrid_scale_model import subgrid_scale_model as subgrid_scale_model_cls
from .les_model_options import les_model_options as les_model_options_cls
from .reynolds_stress_options import reynolds_stress_options as reynolds_stress_options_cls
from .enhanced_wall_treatment_options import enhanced_wall_treatment_options as enhanced_wall_treatment_options_cls
from .rans_model import rans_model as rans_model_cls

class viscous(Group):
    fluent_name = ...
    child_names = ...
    model: model_cls = ...
    options: options_cls = ...
    spalart_allmaras_production: spalart_allmaras_production_cls = ...
    k_epsilon_model: k_epsilon_model_cls = ...
    k_omega_model: k_omega_model_cls = ...
    k_omega_options: k_omega_options_cls = ...
    rng_options: rng_options_cls = ...
    near_wall_treatment: near_wall_treatment_cls = ...
    transition_sst_options: transition_sst_options_cls = ...
    reynolds_stress_model: reynolds_stress_model_cls = ...
    subgrid_scale_model: subgrid_scale_model_cls = ...
    les_model_options: les_model_options_cls = ...
    reynolds_stress_options: reynolds_stress_options_cls = ...
    enhanced_wall_treatment_options: enhanced_wall_treatment_options_cls = ...
    rans_model: rans_model_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .domain import domain as domain_cls
from .cell_zones_1 import cell_zones as cell_zones_cls
from .register_id import register_id as register_id_cls
from .variable import variable as variable_cls
from .patch_velocity import patch_velocity as patch_velocity_cls
from .use_custom_field_function import use_custom_field_function as use_custom_field_function_cls
from .custom_field_function_name import custom_field_function_name as custom_field_function_name_cls
from .value import value as value_cls

class calculate_patch(Command):
    fluent_name = ...
    argument_names = ...
    domain: domain_cls = ...
    cell_zones: cell_zones_cls = ...
    register_id: register_id_cls = ...
    variable: variable_cls = ...
    patch_velocity: patch_velocity_cls = ...
    use_custom_field_function: use_custom_field_function_cls = ...
    custom_field_function_name: custom_field_function_name_cls = ...
    value: value_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .numerical_damping_factor import numerical_damping_factor as numerical_damping_factor_cls
from .enhanced_strain import enhanced_strain as enhanced_strain_cls
from .unsteady_damping_rayleigh import unsteady_damping_rayleigh as unsteady_damping_rayleigh_cls
from .amg_stabilization import amg_stabilization as amg_stabilization_cls
from .max_iter import max_iter as max_iter_cls

class controls(Group):
    fluent_name = ...
    child_names = ...
    numerical_damping_factor: numerical_damping_factor_cls = ...
    enhanced_strain: enhanced_strain_cls = ...
    unsteady_damping_rayleigh: unsteady_damping_rayleigh_cls = ...
    amg_stabilization: amg_stabilization_cls = ...
    max_iter: max_iter_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .viscous_terms import viscous_terms as viscous_terms_cls
from .species_reactions import species_reactions as species_reactions_cls
from .set_turbulent_viscosity_ratio import set_turbulent_viscosity_ratio as set_turbulent_viscosity_ratio_cls
from .reset_to_defaults import reset_to_defaults as reset_to_defaults_cls

class fmg_options(Group):
    """
    Enter the full-multigrid option menu.
    """

    fluent_name = "fmg-options"

    child_names = \
        ['viscous_terms', 'species_reactions',
         'set_turbulent_viscosity_ratio', 'reset_to_defaults']

    _child_classes = dict(
        viscous_terms=viscous_terms_cls,
        species_reactions=species_reactions_cls,
        set_turbulent_viscosity_ratio=set_turbulent_viscosity_ratio_cls,
        reset_to_defaults=reset_to_defaults_cls,
    )

    return_type = "<object object at 0x7fc3bc2a7700>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .origin import origin as origin_cls
from .orientation import orientation as orientation_cls

class initial_state(Group):
    """
    'initial_state' child.
    """

    fluent_name = "initial-state"

    child_names = \
        ['origin', 'orientation']

    _child_classes = dict(
        origin=origin_cls,
        orientation=orientation_cls,
    )

    return_type = "<object object at 0x7fc3bc3aadc0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .diffusion_collision_integral import diffusion_collision_integral as diffusion_collision_integral_cls
from .viscosity_collision_integral import viscosity_collision_integral as viscosity_collision_integral_cls

class neutral_involved_interaction(Group):
    """
    'neutral_involved_interaction' child.
    """

    fluent_name = "neutral-involved-interaction"

    child_names = \
        ['diffusion_collision_integral', 'viscosity_collision_integral']

    _child_classes = dict(
        diffusion_collision_integral=diffusion_collision_integral_cls,
        viscosity_collision_integral=viscosity_collision_integral_cls,
    )

    return_type = "<object object at 0x7f5bb1d0e7c0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .file_path import file_path as file_path_cls

class write_simulation_report_names_to_file(Command):
    """
    Write the list of currently generated report names to a txt file.
    
    Parameters
    ----------
        file_path : str
            'file_path' child.
    
    """

    fluent_name = "write-simulation-report-names-to-file"

    argument_names = \
        ['file_path']

    _child_classes = dict(
        file_path=file_path_cls,
    )

    return_type = "<object object at 0x7fc3a7f861a0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .name_2 import name as name_cls
from .retain_instantaneous_values import retain_instantaneous_values as retain_instantaneous_values_cls
from .list_valid_report_names import list_valid_report_names as list_valid_report_names_cls
from .define import define as define_cls
from .average_over import average_over as average_over_cls
from .old_props import old_props as old_props_cls

class single_val_expression_child(Group):
    fluent_name = ...
    child_names = ...
    name: name_cls = ...
    retain_instantaneous_values: retain_instantaneous_values_cls = ...
    list_valid_report_names: list_valid_report_names_cls = ...
    define: define_cls = ...
    average_over: average_over_cls = ...
    old_props: old_props_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .write_summary_to_file import write_summary_to_file as write_summary_to_file_cls
from .file_name_1 import file_name as file_name_cls
from .include_in_domains_particles import include_in_domains_particles as include_in_domains_particles_cls
from .pick_injection import pick_injection as pick_injection_cls
from .injection_1 import injection as injection_cls

class extended_summary(Command):
    fluent_name = ...
    argument_names = ...
    write_summary_to_file: write_summary_to_file_cls = ...
    file_name: file_name_cls = ...
    include_in_domains_particles: include_in_domains_particles_cls = ...
    pick_injection: pick_injection_cls = ...
    injection: injection_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .surface import surface as surface_cls

class delete(CommandWithPositionalArgs):
    """
    Delete surface mesh.
    
    Parameters
    ----------
        surface : str
            'surface' child.
    
    """

    fluent_name = "delete"

    argument_names = \
        ['surface']

    _child_classes = dict(
        surface=surface_cls,
    )

    return_type = "<object object at 0x7f5c26923930>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .interpolate_flow_cp import interpolate_flow_cp as interpolate_flow_cp_cls
from .interpolate_flow_density import interpolate_flow_density as interpolate_flow_density_cls
from .interpolate_flow_solution_gradients import interpolate_flow_solution_gradients as interpolate_flow_solution_gradients_cls
from .interpolate_flow_viscosity import interpolate_flow_viscosity as interpolate_flow_viscosity_cls
from .interpolate_temperature import interpolate_temperature as interpolate_temperature_cls
from .zero_nodal_velocities_on_walls import zero_nodal_velocities_on_walls as zero_nodal_velocities_on_walls_cls

class interpolation(Group):
    fluent_name = ...
    child_names = ...
    interpolate_flow_cp: interpolate_flow_cp_cls = ...
    interpolate_flow_density: interpolate_flow_density_cls = ...
    interpolate_flow_solution_gradients: interpolate_flow_solution_gradients_cls = ...
    interpolate_flow_viscosity: interpolate_flow_viscosity_cls = ...
    interpolate_temperature: interpolate_temperature_cls = ...
    zero_nodal_velocities_on_walls: zero_nodal_velocities_on_walls_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .flow_rate import flow_rate as flow_rate_cls
from .flow_rate_2 import flow_rate_2 as flow_rate_2_cls
from .total_flow_rate import total_flow_rate as total_flow_rate_cls
from .scale_by_area import scale_by_area as scale_by_area_cls

class flow_rate(Group):
    fluent_name = ...
    child_names = ...
    flow_rate: flow_rate_cls = ...
    flow_rate_2: flow_rate_2_cls = ...
    total_flow_rate: total_flow_rate_cls = ...
    scale_by_area: scale_by_area_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .change_type import change_type as change_type_cls
from .axis_child import axis_child


class shadow(NamedObject[axis_child], CreatableNamedObjectMixinOld[axis_child]):
    """
    'shadow' child.
    """

    fluent_name = "shadow"

    command_names = \
        ['change_type']

    _child_classes = dict(
        change_type=change_type_cls,
    )

    child_object_type: axis_child = axis_child
    """
    child_object_type of shadow.
    """
    return_type = "<object object at 0x7ff7035d0590>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .wall_treatment import wall_treatment as wall_treatment_cls
from .user_defined import user_defined as user_defined_cls
from .enhanced_wall_treatment_options import enhanced_wall_treatment_options as enhanced_wall_treatment_options_cls
from .wall_omega_treatment import wall_omega_treatment as wall_omega_treatment_cls

class near_wall_treatment(Group):
    fluent_name = ...
    child_names = ...
    wall_treatment: wall_treatment_cls = ...
    user_defined: user_defined_cls = ...
    enhanced_wall_treatment_options: enhanced_wall_treatment_options_cls = ...
    wall_omega_treatment: wall_omega_treatment_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .geom_disable import geom_disable as geom_disable_cls
from .geom_dir_spec import geom_dir_spec as geom_dir_spec_cls
from .geom_dir_x import geom_dir_x as geom_dir_x_cls
from .geom_dir_y import geom_dir_y as geom_dir_y_cls
from .geom_dir_z import geom_dir_z as geom_dir_z_cls
from .geom_levels import geom_levels as geom_levels_cls
from .geom_bgthread import geom_bgthread as geom_bgthread_cls
from .flowrate_frac import flowrate_frac as flowrate_frac_cls
from .elec_potential_type import elec_potential_type as elec_potential_type_cls
from .potential_value import potential_value as potential_value_cls
from .dual_potential_type import dual_potential_type as dual_potential_type_cls
from .dual_potential_value import dual_potential_value as dual_potential_value_cls
from .x_displacement_type import x_displacement_type as x_displacement_type_cls
from .x_displacement_value import x_displacement_value as x_displacement_value_cls
from .y_displacement_type import y_displacement_type as y_displacement_type_cls
from .y_displacement_value import y_displacement_value as y_displacement_value_cls
from .z_displacement_type import z_displacement_type as z_displacement_type_cls
from .z_displacement_value import z_displacement_value as z_displacement_value_cls
from .uds_bc import uds_bc as uds_bc_cls
from .uds import uds as uds_cls
from .radiation_bc import radiation_bc as radiation_bc_cls
from .coll_dtheta import coll_dtheta as coll_dtheta_cls
from .coll_dphi import coll_dphi as coll_dphi_cls
from .band_q_irrad import band_q_irrad as band_q_irrad_cls
from .band_q_irrad_diffuse import band_q_irrad_diffuse as band_q_irrad_diffuse_cls
from .parallel_collimated_beam import parallel_collimated_beam as parallel_collimated_beam_cls
from .solar_direction import solar_direction as solar_direction_cls
from .solar_irradiation import solar_irradiation as solar_irradiation_cls
from .t_b_b_spec import t_b_b_spec as t_b_b_spec_cls
from .t_b_b import t_b_b as t_b_b_cls
from .in_emiss import in_emiss as in_emiss_cls
from .dpm_bc_type import dpm_bc_type as dpm_bc_type_cls
from .dpm_bc_collision_partner import dpm_bc_collision_partner as dpm_bc_collision_partner_cls
from .reinj_inj import reinj_inj as reinj_inj_cls
from .dpm_bc_udf import dpm_bc_udf as dpm_bc_udf_cls
from .solar_fluxes import solar_fluxes as solar_fluxes_cls
from .solar_shining_factor import solar_shining_factor as solar_shining_factor_cls
from .radiating_s2s_surface import radiating_s2s_surface as radiating_s2s_surface_cls

class phase_child(Group):
    """
    'child_object_type' of phase.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['geom_disable', 'geom_dir_spec', 'geom_dir_x', 'geom_dir_y',
         'geom_dir_z', 'geom_levels', 'geom_bgthread', 'flowrate_frac',
         'elec_potential_type', 'potential_value', 'dual_potential_type',
         'dual_potential_value', 'x_displacement_type',
         'x_displacement_value', 'y_displacement_type',
         'y_displacement_value', 'z_displacement_type',
         'z_displacement_value', 'uds_bc', 'uds', 'radiation_bc',
         'coll_dtheta', 'coll_dphi', 'band_q_irrad', 'band_q_irrad_diffuse',
         'parallel_collimated_beam', 'solar_direction', 'solar_irradiation',
         't_b_b_spec', 't_b_b', 'in_emiss', 'dpm_bc_type',
         'dpm_bc_collision_partner', 'reinj_inj', 'dpm_bc_udf',
         'solar_fluxes', 'solar_shining_factor', 'radiating_s2s_surface']

    _child_classes = dict(
        geom_disable=geom_disable_cls,
        geom_dir_spec=geom_dir_spec_cls,
        geom_dir_x=geom_dir_x_cls,
        geom_dir_y=geom_dir_y_cls,
        geom_dir_z=geom_dir_z_cls,
        geom_levels=geom_levels_cls,
        geom_bgthread=geom_bgthread_cls,
        flowrate_frac=flowrate_frac_cls,
        elec_potential_type=elec_potential_type_cls,
        potential_value=potential_value_cls,
        dual_potential_type=dual_potential_type_cls,
        dual_potential_value=dual_potential_value_cls,
        x_displacement_type=x_displacement_type_cls,
        x_displacement_value=x_displacement_value_cls,
        y_displacement_type=y_displacement_type_cls,
        y_displacement_value=y_displacement_value_cls,
        z_displacement_type=z_displacement_type_cls,
        z_displacement_value=z_displacement_value_cls,
        uds_bc=uds_bc_cls,
        uds=uds_cls,
        radiation_bc=radiation_bc_cls,
        coll_dtheta=coll_dtheta_cls,
        coll_dphi=coll_dphi_cls,
        band_q_irrad=band_q_irrad_cls,
        band_q_irrad_diffuse=band_q_irrad_diffuse_cls,
        parallel_collimated_beam=parallel_collimated_beam_cls,
        solar_direction=solar_direction_cls,
        solar_irradiation=solar_irradiation_cls,
        t_b_b_spec=t_b_b_spec_cls,
        t_b_b=t_b_b_cls,
        in_emiss=in_emiss_cls,
        dpm_bc_type=dpm_bc_type_cls,
        dpm_bc_collision_partner=dpm_bc_collision_partner_cls,
        reinj_inj=reinj_inj_cls,
        dpm_bc_udf=dpm_bc_udf_cls,
        solar_fluxes=solar_fluxes_cls,
        solar_shining_factor=solar_shining_factor_cls,
        radiating_s2s_surface=radiating_s2s_surface_cls,
    )

    return_type = "<object object at 0x7ff703bd0b10>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .smoothing_iteration import smoothing_iteration as smoothing_iteration_cls

class smooth_partition(Command):
    """
    Smooth partition interface.
    
    Parameters
    ----------
        smoothing_iteration : int
            Set maximum number of smoothing iterations.
    
    """

    fluent_name = "smooth-partition"

    argument_names = \
        ['smoothing_iteration']

    _child_classes = dict(
        smoothing_iteration=smoothing_iteration_cls,
    )

    return_type = "<object object at 0x7f5bb1149680>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .pv_coupling_controls import pv_coupling_controls as pv_coupling_controls_cls
from .pv_coupling_method import pv_coupling_method as pv_coupling_method_cls
from .gradient_controls import gradient_controls as gradient_controls_cls
from .specify_gradient_method import specify_gradient_method as specify_gradient_method_cls

class methods(Group):
    """
    'methods' child.
    """

    fluent_name = "methods"

    child_names = \
        ['pv_coupling_controls', 'pv_coupling_method', 'gradient_controls',
         'specify_gradient_method']

    _child_classes = dict(
        pv_coupling_controls=pv_coupling_controls_cls,
        pv_coupling_method=pv_coupling_method_cls,
        gradient_controls=gradient_controls_cls,
        specify_gradient_method=specify_gradient_method_cls,
    )

    return_type = "<object object at 0x7fc3bc2a4460>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .border_4 import border as border_cls
from .bottom_4 import bottom as bottom_cls
from .left_4 import left as left_cls
from .right_5 import right as right_cls
from .top_4 import top as top_cls
from .visible_5 import visible as visible_cls

class xy(Group):
    fluent_name = ...
    child_names = ...
    border: border_cls = ...
    bottom: bottom_cls = ...
    left: left_cls = ...
    right: right_cls = ...
    top: top_cls = ...
    visible: visible_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .surface_id_val import surface_id_val as surface_id_val_cls
from .min_feature_size import min_feature_size as min_feature_size_cls
from .proj_plane_norm_comp import proj_plane_norm_comp as proj_plane_norm_comp_cls

class projected_surface_area(Command):
    """
    Print total area of the projection of a group of surfaces to a plane.
    
    Parameters
    ----------
        surface_id_val : List
            'surface_id_val' child.
        min_feature_size : real
            'min_feature_size' child.
        proj_plane_norm_comp : Tuple
            'proj_plane_norm_comp' child.
    
    """

    fluent_name = "projected-surface-area"

    argument_names = \
        ['surface_id_val', 'min_feature_size', 'proj_plane_norm_comp']

    _child_classes = dict(
        surface_id_val=surface_id_val_cls,
        min_feature_size=min_feature_size_cls,
        proj_plane_norm_comp=proj_plane_norm_comp_cls,
    )

    return_type = "<object object at 0x7f5bb1148c00>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .option_3 import option as option_cls
from .shape_factor import shape_factor as shape_factor_cls
from .cunningham_factor import cunningham_factor as cunningham_factor_cls

class particle_drag(Group):
    fluent_name = ...
    child_names = ...
    option: option_cls = ...
    shape_factor: shape_factor_cls = ...
    cunningham_factor: cunningham_factor_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .general import general as general_cls
from .models_1 import models as models_cls
from .materials import materials as materials_cls
from .cell_zone_conditions import cell_zone_conditions as cell_zone_conditions_cls
from .boundary_conditions import boundary_conditions as boundary_conditions_cls
from .reference_values import reference_values as reference_values_cls
from .named_expressions import named_expressions as named_expressions_cls

class setup(Group):
    fluent_name = ...
    child_names = ...
    general: general_cls = ...
    models: models_cls = ...
    materials: materials_cls = ...
    cell_zone_conditions: cell_zone_conditions_cls = ...
    boundary_conditions: boundary_conditions_cls = ...
    reference_values: reference_values_cls = ...
    named_expressions: named_expressions_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .recommended_defaults_for_existing_cases import recommended_defaults_for_existing_cases as recommended_defaults_for_existing_cases_cls
from .revert_to_pre_r20_1_default_settings import revert_to_pre_r20_1_default_settings as revert_to_pre_r20_1_default_settings_cls

class default_controls(Group):
    """
    'default_controls' child.
    """

    fluent_name = "default-controls"

    child_names = \
        ['recommended_defaults_for_existing_cases',
         'revert_to_pre_r20_1_default_settings']

    _child_classes = dict(
        recommended_defaults_for_existing_cases=recommended_defaults_for_existing_cases_cls,
        revert_to_pre_r20_1_default_settings=revert_to_pre_r20_1_default_settings_cls,
    )

    return_type = "<object object at 0x7ff703161760>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .iter_count import iter_count as iter_count_cls
from .solution_stabilization_persistence import solution_stabilization_persistence as solution_stabilization_persistence_cls
from .persistence_fixed_time_steps import persistence_fixed_time_steps as persistence_fixed_time_steps_cls
from .persistence_fixed_duration import persistence_fixed_duration as persistence_fixed_duration_cls
from .extrapolation_method import extrapolation_method as extrapolation_method_cls

class parameters(Group):
    """
    'parameters' child.
    """

    fluent_name = "parameters"

    child_names = \
        ['iter_count', 'solution_stabilization_persistence',
         'persistence_fixed_time_steps', 'persistence_fixed_duration',
         'extrapolation_method']

    _child_classes = dict(
        iter_count=iter_count_cls,
        solution_stabilization_persistence=solution_stabilization_persistence_cls,
        persistence_fixed_time_steps=persistence_fixed_time_steps_cls,
        persistence_fixed_duration=persistence_fixed_duration_cls,
        extrapolation_method=extrapolation_method_cls,
    )

    return_type = "<object object at 0x7fc3bc2a4260>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .list import list as list_cls
from .list_properties import list_properties as list_properties_cls
from .duplicate import duplicate as duplicate_cls
from .use_active import use_active as use_active_cls
from .restore_state import restore_state as restore_state_cls
from .copy_5 import copy as copy_cls
from .read_3 import read as read_cls
from .write_1 import write as write_cls
from .display_states_child import display_states_child


class display_states(NamedObject[display_states_child], CreatableNamedObjectMixinOld[display_states_child]):
    """
    'display_states' child.
    """

    fluent_name = "display-states"

    command_names = \
        ['list', 'list_properties', 'duplicate', 'use_active',
         'restore_state', 'copy', 'read', 'write']

    _child_classes = dict(
        list=list_cls,
        list_properties=list_properties_cls,
        duplicate=duplicate_cls,
        use_active=use_active_cls,
        restore_state=restore_state_cls,
        copy=copy_cls,
        read=read_cls,
        write=write_cls,
    )

    child_object_type: display_states_child = display_states_child
    """
    child_object_type of display_states.
    """
    return_type = "<object object at 0x7fc3a7f84d00>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .list_properties_1 import list_properties as list_properties_cls
from .wave_list_shallow_child import wave_list_shallow_child


class wave_list_shallow(ListObject[wave_list_shallow_child]):
    """
    'wave_list_shallow' child.
    """

    fluent_name = "wave-list-shallow"

    command_names = \
        ['list_properties']

    _child_classes = dict(
        list_properties=list_properties_cls,
    )

    child_object_type: wave_list_shallow_child = wave_list_shallow_child
    """
    child_object_type of wave_list_shallow.
    """
    return_type = "<object object at 0x7fc3bc78b1f0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .control_by import control_by as control_by_cls
from .max_number_of_steps import max_number_of_steps as max_number_of_steps_cls
from .length_scale import length_scale as length_scale_cls
from .step_length_factor import step_length_factor as step_length_factor_cls

class tracking_parameters(Group):
    fluent_name = ...
    child_names = ...
    control_by: control_by_cls = ...
    max_number_of_steps: max_number_of_steps_cls = ...
    length_scale: length_scale_cls = ...
    step_length_factor: step_length_factor_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .graphics import graphics as graphics_cls
from .scene import scene as scene_cls
from .surfaces_2 import surfaces as surfaces_cls
from .animations import animations as animations_cls
from .plot_2 import plot as plot_cls
from .report_1 import report as report_cls

class results(Group):
    """
    'results' child.
    """

    fluent_name = "results"

    child_names = \
        ['graphics', 'scene', 'surfaces', 'animations', 'plot', 'report']

    _child_classes = dict(
        graphics=graphics_cls,
        scene=scene_cls,
        surfaces=surfaces_cls,
        animations=animations_cls,
        plot=plot_cls,
        report=report_cls,
    )

    return_type = "<object object at 0x7f5bb1148e40>"



"""Provide a module to generate the Fluent settings tree.

Running this module generates a python module with the definition of the Fluent
settings classes. The out is placed at:

- src/ansys/fluent/core/solver/settings.py

Running this module requires Fluent to be installed.

Process
-------
    - Launch fluent and get static info. Parse the class with flobject.get_cls()
    - Generate a dictionary of unique classes with their hash as a key and a tuple of cls, children hash, commands hash, arguments hash, child object type hash as value.
    - - This eliminates reduandancy and only unique classes are written.
    - Generate .py files for the classes in hash dictionary. Resolve named conflicts with integer suffix.
    - - Populate files dictionary with hash as key and file name as value.
    - - child_object_type handled specially to avoid a lot of files with same name and to provide more insight of the child.
    - Populate the classes.
    - - For writing the import statements, get the hash of the child/command/argument/named object stored in the hash dict tuple value.
    - - Use that hash to locate the corresponding children file name in the hash dict.

Usage
-----
python <path to settingsgen.py>
"""

import hashlib
import io
import os
from pathlib import Path
import pickle
import pprint
import shutil

import ansys.fluent.core as pyfluent
from ansys.fluent.core import launch_fluent
from ansys.fluent.core.codegen import StaticInfoType
from ansys.fluent.core.solver import flobject
from ansys.fluent.core.utils.fix_doc import fix_settings_doc
from ansys.fluent.core.utils.fluent_version import get_version_for_file_name

hash_dict = {}
files_dict = {}
root_class_path = ""


def _gethash(obj_info):
    dhash = hashlib.sha256()
    dhash.update(pickle.dumps(obj_info))
    return dhash.hexdigest()


def _get_indent_str(indent):
    return f"{' '*indent*4}"


def _populate_hash_dict(name, info, cls, api_tree):
    children = info.get("children")
    if children:
        children_hash = []
        for cname, cinfo in children.items():
            for child in getattr(cls, "child_names", None):
                child_cls = cls._child_classes[child]
                if cname == child_cls.fluent_name:
                    api_tree[child] = {}
                    children_hash.append(
                        _populate_hash_dict(cname, cinfo, child_cls, api_tree[child])
                    )
                    okey = f"{child}:<name>"
                    if okey in api_tree[child]:
                        api_tree[child].update(api_tree[child][okey])
                        del api_tree[child][okey]
                        api_tree[okey] = api_tree.pop(child)
                    else:
                        api_tree[child] = api_tree[child] or "Parameter"
                    break
    else:
        children_hash = None

    commands = info.get("commands")
    if commands:
        commands_hash = []
        for cname, cinfo in commands.items():
            for command in getattr(cls, "command_names", None):
                command_cls = cls._child_classes[command]
                if cname == command_cls.fluent_name:
                    api_tree[command] = "Command"
                    commands_hash.append(
                        _populate_hash_dict(cname, cinfo, command_cls, {})
                    )
                    break
    else:
        commands_hash = None

    queries = info.get("queries")
    if queries:
        queries_hash = []
        for qname, qinfo in queries.items():
            for query in getattr(cls, "query_names", None):
                query_cls = cls._child_classes[query]
                if qname == query_cls.fluent_name:
                    api_tree[query] = "Query"
                    queries_hash.append(
                        _populate_hash_dict(qname, qinfo, query_cls, {})
                    )
                    break
    else:
        queries_hash = None

    arguments = info.get("arguments")
    if arguments:
        arguments_hash = []
        for aname, ainfo in arguments.items():
            for argument in getattr(cls, "argument_names", None):
                argument_cls = cls._child_classes[argument]
                if aname == argument_cls.fluent_name:
                    arguments_hash.append(
                        _populate_hash_dict(aname, ainfo, argument_cls, {})
                    )
                    break
    else:
        arguments_hash = None

    object_type = info.get("object-type")
    if object_type:
        key = f"{cls.__name__}:<name>"
        api_tree[key] = {}
        object_hash = _populate_hash_dict(
            "child-object-type",
            object_type,
            getattr(cls, "child_object_type", None),
            api_tree[key],
        )
    else:
        object_hash = None

    cls_tuple = (
        name,
        cls.__name__,
        cls.__bases__,
        info["type"],
        info.get("help"),
        children_hash,
        commands_hash,
        queries_hash,
        arguments_hash,
        object_hash,
    )
    hash = _gethash(cls_tuple)
    if not hash_dict.get(hash):
        hash_dict[hash] = (
            cls,
            children_hash,
            commands_hash,
            queries_hash,
            arguments_hash,
            object_hash,
        )
    return hash


class _CommandInfo:
    def __init__(self, doc, args_info):
        self.doc = doc
        self.args_info = args_info


_arg_type_strings = {
    flobject.Boolean: "bool",
    flobject.Integer: "int",
    flobject.Real: "Union[float, str]",
    flobject.String: "str",
    flobject.Filename: "str",
    flobject.BooleanList: "List[bool]",
    flobject.IntegerList: "List[int]",
    flobject.RealVector: "Tuple[Union[float, str], Union[float, str], Union[float, str]",
    flobject.RealList: "List[Union[float, str]]",
    flobject.StringList: "List[str]",
    flobject.FilenameList: "List[str]",
}


def _get_commands_info(commands_hash):
    commands_info = {}
    for command_hash in commands_hash:
        command_hash_info = hash_dict.get(command_hash)
        command_cls = command_hash_info[0]
        command_name = command_cls.__name__
        command_info = _CommandInfo(command_cls.__doc__, [])
        if command_hash_info[4]:
            for arg_hash in command_hash_info[4]:
                arg_hash_info = hash_dict.get(arg_hash)
                arg_cls = arg_hash_info[0]
                arg_name = arg_cls.__name__
                arg_type = _arg_type_strings[arg_cls.__bases__[0]]
                command_info.args_info.append(f"{arg_name}: {arg_type}")
        commands_info[command_name] = command_info
    return commands_info


def _write_doc_string(doc, indent, writer):
    doc = ("\n" + indent).join(doc.split("\n"))
    writer.write(f'{indent}"""\n')
    writer.write(f"{indent}{doc}")
    writer.write(f'\n{indent}"""\n\n')


def _populate_classes(parent_dir):
    istr = _get_indent_str(0)
    istr1 = _get_indent_str(1)
    istr2 = _get_indent_str(2)
    files = []
    # generate files
    for key, (
        cls,
        children_hash,
        commands_hash,
        queries_hash,
        arguments_hash,
        object_hash,
    ) in hash_dict.items():
        cls_name = file_name = cls.__name__
        if cls_name == "child_object_type":
            # Get the first parent for this class.
            for (
                cls1,
                children_hash1,
                commands_hash1,
                queries_hash1,
                arguments_hash1,
                object_hash1,
            ) in hash_dict.values():
                if key == object_hash1:
                    cls.__name__ = file_name = cls1.__name__ + "_child"
                    break
        i = 0
        while file_name in files:
            if i > 0:
                file_name = file_name[: file_name.rfind("_")]
            i += 1
            file_name += "_" + str(i)
        files.append(file_name)
        files_dict[key] = file_name

        # Store root class path for __init__.py
        if cls_name == "root":
            global root_class_path
            root_class_path = file_name

        file_name += ".py"
        file_name = os.path.normpath(os.path.join(parent_dir, file_name))
        with open(file_name, "w") as f:
            f.write(f"name: {cls_name}")

    # populate files
    for key, (
        cls,
        children_hash,
        commands_hash,
        queries_hash,
        arguments_hash,
        object_hash,
    ) in hash_dict.items():
        file_name = files_dict.get(key)
        cls_name = cls.__name__
        file_name = os.path.normpath(os.path.join(parent_dir, file_name + ".py"))
        stub_f = None
        if not pyfluent.CODEGEN_ZIP_SETTINGS:
            stub_file_name = file_name + "i"
            stub_f = open(stub_file_name, "w")
        with open(file_name, "w") as f:
            # disclaimer to py file
            f.write("#\n")
            f.write("# This is an auto-generated file.  DO NOT EDIT!\n")
            f.write("#\n")
            f.write("\n")
            if stub_f:
                stub_f.write("#\n")
                stub_f.write("# This is an auto-generated file.  DO NOT EDIT!\n")
                stub_f.write("#\n")
                stub_f.write("\n\n")

            # write imports to py file
            import_str = (
                "from ansys.fluent.core.solver.flobject import *\n\n"
                "from ansys.fluent.core.solver.flobject import (\n"
                f"{istr1}_ChildNamedObjectAccessorMixin,\n"
                f"{istr1}CreatableNamedObjectMixin,\n"
                f"{istr1}_NonCreatableNamedObjectMixin,\n"
                f"{istr1}AllowedValuesMixin,\n"
                f"{istr1}_InputFile,\n"
                f"{istr1}_OutputFile,\n"
                f"{istr1}_InOutFile,\n"
                ")\n\n"
            )
            f.write(import_str)
            if stub_f:
                stub_f.write(import_str)
                stub_f.write("from typing import Union, List, Tuple\n\n")

            if children_hash:
                for child in children_hash:
                    pchild_name = hash_dict.get(child)[0].__name__
                    import_str = f"from .{files_dict.get(child)} import {pchild_name} as {pchild_name}_cls\n"
                    f.write(import_str)
                    if stub_f:
                        stub_f.write(import_str)

            if commands_hash:
                for child in commands_hash:
                    pchild_name = hash_dict.get(child)[0].__name__
                    import_str = f"from .{files_dict.get(child)} import {pchild_name} as {pchild_name}_cls\n"
                    f.write(import_str)
                    if stub_f:
                        stub_f.write(import_str)

            if queries_hash:
                for child in queries_hash:
                    pchild_name = hash_dict.get(child)[0].__name__
                    import_str = f"from .{files_dict.get(child)} import {pchild_name} as {pchild_name}_cls\n"
                    f.write(import_str)
                    if stub_f:
                        stub_f.write(import_str)

            if arguments_hash:
                for child in arguments_hash:
                    pchild_name = hash_dict.get(child)[0].__name__
                    import_str = f"from .{files_dict.get(child)} import {pchild_name} as {pchild_name}_cls\n"
                    f.write(import_str)
                    if stub_f:
                        stub_f.write(import_str)

            if object_hash:
                pchild_name = hash_dict.get(object_hash)[0].__name__
                import_str = (
                    f"from .{files_dict.get(object_hash)} import {pchild_name}\n\n"
                )
                f.write(import_str)
                if stub_f:
                    stub_f.write(import_str)

            # class name
            class_def_str = (
                f"\n{istr}class {cls_name}"
                f'({", ".join(f"{c.__name__}[{hash_dict.get(object_hash)[0].__name__}]" if object_hash else c.__name__ for c in cls.__bases__)}):\n'
            )
            f.write(class_def_str)
            if stub_f:
                stub_f.write(class_def_str)

            doc = fix_settings_doc(cls.__doc__)
            # Custom doc for child object type
            if cls.fluent_name == "child-object-type":
                parent_name = Path(file_name).stem[
                    0 : Path(file_name).stem.find("_child")
                ]
                doc = f"'child_object_type' of {parent_name}."

            _write_doc_string(doc, istr1, f)
            f.write(f'{istr1}fluent_name = "{cls.fluent_name}"\n\n')
            if stub_f:
                stub_f.write(f"{istr1}fluent_name = ...\n")

            child_class_strings = []

            # write children objects
            child_names = getattr(cls, "child_names", None)
            if child_names:
                f.write(f"{istr1}child_names = \\\n")
                strout = io.StringIO()
                pprint.pprint(child_names, stream=strout, compact=True, width=70)
                mn = ("\n" + istr2).join(strout.getvalue().strip().split("\n"))
                f.write(f"{istr2}{mn}\n\n")
                if stub_f:
                    stub_f.write(f"{istr1}child_names = ...\n")

                for child in child_names:
                    child_cls = cls._child_classes[child]
                    child_class_strings.append(f"{child}={child_cls.__name__}_cls")
                    if stub_f:
                        stub_f.write(
                            f"{istr1}{child}: {child_cls.__name__}_cls = ...\n"
                        )

            # write command objects
            command_names = getattr(cls, "command_names", None)
            if command_names:
                f.write(f"{istr1}command_names = \\\n")
                strout = io.StringIO()
                pprint.pprint(command_names, stream=strout, compact=True, width=70)
                mn = ("\n" + istr2).join(strout.getvalue().strip().split("\n"))
                f.write(f"{istr2}{mn}\n\n")
                if stub_f:
                    stub_f.write(f"{istr1}command_names = ...\n\n")

                commands_info = _get_commands_info(commands_hash)
                for command in command_names:
                    command_cls = cls._child_classes[command]
                    child_class_strings.append(f"{command}={command_cls.__name__}_cls")
                    # function annotation for commands
                    command_info = commands_info[command]
                    if stub_f:
                        stub_f.write(f"{istr1}def {command}(self, ")
                        stub_f.write(", ".join(command_info.args_info))
                        stub_f.write("):\n")
                        _write_doc_string(command_info.doc, istr2, stub_f)

            # write query objects
            query_names = getattr(cls, "query_names", None)
            if query_names:
                f.write(f"{istr1}query_names = \\\n")
                strout = io.StringIO()
                pprint.pprint(query_names, stream=strout, compact=True, width=70)
                mn = ("\n" + istr2).join(strout.getvalue().strip().split("\n"))
                f.write(f"{istr2}{mn}\n\n")
                if stub_f:
                    stub_f.write(f"{istr1}query_names = ...\n\n")

                queries_info = _get_commands_info(queries_hash)
                for query in query_names:
                    query_cls = cls._child_classes[query]
                    child_class_strings.append(f"{query}={query_cls.__name__}_cls")
                    # function annotation for queries
                    query_info = queries_info[query]
                    if stub_f:
                        stub_f.write(f"{istr1}def {query}(self, ")
                        stub_f.write(", ".join(query_info.args_info))
                        stub_f.write("):\n")
                        _write_doc_string(query_info.doc, istr2, stub_f)

            # write arguments
            arguments = getattr(cls, "argument_names", None)
            if arguments:
                f.write(f"{istr1}argument_names = \\\n")
                strout = io.StringIO()
                pprint.pprint(arguments, stream=strout, compact=True, width=70)
                mn = ("\n" + istr2).join(strout.getvalue().strip().split("\n"))
                f.write(f"{istr2}{mn}\n\n")
                if stub_f:
                    stub_f.write(f"{istr1}argument_names = ...\n")

                for argument in arguments:
                    argument_cls = cls._child_classes[argument]
                    child_class_strings.append(
                        f"{argument}={argument_cls.__name__}_cls"
                    )
                    if stub_f:
                        stub_f.write(
                            f"{istr1}{argument}: {argument_cls.__name__}_cls = ...\n"
                        )

            if child_class_strings:
                f.write(f"{istr1}_child_classes = dict(\n")
                f.writelines(
                    [f"{istr2}{cls_str},\n" for cls_str in child_class_strings]
                )
                f.write(f"{istr1})\n\n")

            child_aliases = getattr(cls, "_child_aliases", None)
            if child_aliases:
                f.write(f"{istr1}_child_aliases = dict(\n")
                f.writelines([f'{istr2}{k}="{v}",\n' for k, v in child_aliases.items()])
                f.write(f"{istr1})\n\n")

            # write object type
            child_object_type = getattr(cls, "child_object_type", None)
            if child_object_type:
                f.write(f"{istr1}child_object_type: {pchild_name} = {pchild_name}\n")
                f.write(f'{istr1}"""\n')
                f.write(f"{istr1}child_object_type of {cls_name}.")
                f.write(f'\n{istr1}"""\n')
                if stub_f:
                    stub_f.write(f"{istr1}child_object_type: {pchild_name} = ...\n")

            return_type = getattr(cls, "return_type", None)
            if return_type:
                f.write(f'{istr1}return_type = "{return_type}"\n')
                if stub_f:
                    stub_f.write(f"{istr1}return_type = ...\n")
            if stub_f:
                stub_f.close()


def _populate_init(parent_dir, hash):
    file_name = os.path.normpath(os.path.join(parent_dir, "__init__.py"))
    with open(file_name, "w") as f:
        f.write("#\n")
        f.write("# This is an auto-generated file.  DO NOT EDIT!\n")
        f.write("#\n")
        f.write("\n")
        f.write(f'"""A package providing Fluent\'s Settings Objects in Python."""')
        f.write("\n")
        f.write("from ansys.fluent.core.solver.flobject import *\n\n")
        f.write(f'SHASH = "{hash}"\n')
        f.write(f"from .{root_class_path} import root")


def generate(version, static_infos: dict):
    """Generate settings API classes."""
    parent_dir = (pyfluent.CODEGEN_OUTDIR / "solver" / f"settings_{version}").resolve()
    api_tree = {}
    sinfo = static_infos.get(StaticInfoType.SETTINGS)

    # Clear previously generated data
    if os.path.exists(parent_dir):
        shutil.rmtree(parent_dir)

    if sinfo:
        hash = _gethash(sinfo)
        os.makedirs(parent_dir)

        if pyfluent.CODEGEN_ZIP_SETTINGS:
            parent_dir = parent_dir / "settings"
            os.makedirs(parent_dir)

        cls, _ = flobject.get_cls("", sinfo, version=version)

        _populate_hash_dict("", sinfo, cls, api_tree)
        _populate_classes(parent_dir)
        _populate_init(parent_dir, hash)

        if pyfluent.CODEGEN_ZIP_SETTINGS:
            shutil.make_archive(parent_dir.parent, "zip", parent_dir.parent)
            shutil.rmtree(parent_dir.parent)

    return {"<solver_session>": api_tree}


if __name__ == "__main__":
    solver = launch_fluent()
    version = get_version_for_file_name(session=solver)
    static_infos = {StaticInfoType.SETTINGS: solver._settings_service.get_static_info()}
    generate(version, static_infos)



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .name_1 import name as name_cls
from .field import field as field_cls
from .filled import filled as filled_cls
from .boundary_values import boundary_values as boundary_values_cls
from .contour_lines import contour_lines as contour_lines_cls
from .node_values import node_values as node_values_cls
from .surfaces_list import surfaces_list as surfaces_list_cls
from .range_option import range_option as range_option_cls
from .coloring import coloring as coloring_cls
from .color_map import color_map as color_map_cls
from .draw_mesh import draw_mesh as draw_mesh_cls
from .mesh_object import mesh_object as mesh_object_cls
from .display_state_name import display_state_name as display_state_name_cls
from .physics import physics as physics_cls
from .geometry_3 import geometry as geometry_cls
from .surfaces import surfaces as surfaces_cls
from .deformation import deformation as deformation_cls
from .deformation_scale import deformation_scale as deformation_scale_cls
from .display_2 import display as display_cls

class contour_child(Group):
    """
    'child_object_type' of contour.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'field', 'filled', 'boundary_values', 'contour_lines',
         'node_values', 'surfaces_list', 'range_option', 'coloring',
         'color_map', 'draw_mesh', 'mesh_object', 'display_state_name',
         'physics', 'geometry', 'surfaces', 'deformation',
         'deformation_scale']

    command_names = \
        ['display']

    _child_classes = dict(
        name=name_cls,
        field=field_cls,
        filled=filled_cls,
        boundary_values=boundary_values_cls,
        contour_lines=contour_lines_cls,
        node_values=node_values_cls,
        surfaces_list=surfaces_list_cls,
        range_option=range_option_cls,
        coloring=coloring_cls,
        color_map=color_map_cls,
        draw_mesh=draw_mesh_cls,
        mesh_object=mesh_object_cls,
        display_state_name=display_state_name_cls,
        physics=physics_cls,
        geometry=geometry_cls,
        surfaces=surfaces_cls,
        deformation=deformation_cls,
        deformation_scale=deformation_scale_cls,
        display=display_cls,
    )

    return_type = "<object object at 0x7f5bb135b550>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .enable_5 import enable as enable_cls
from .drag_law import drag_law as drag_law_cls
from .lift_law import lift_law as lift_law_cls

class particle_rotation(Group):
    fluent_name = ...
    child_names = ...
    enable: enable_cls = ...
    drag_law: drag_law_cls = ...
    lift_law: lift_law_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .multi_grid_controls import multi_grid_controls as multi_grid_controls_cls
from .algebric_mg_controls import algebric_mg_controls as algebric_mg_controls_cls
from .fas_mg_controls import fas_mg_controls as fas_mg_controls_cls
from .amg_gpgpu_options import amg_gpgpu_options as amg_gpgpu_options_cls

class multi_grid(Group):
    fluent_name = ...
    child_names = ...
    multi_grid_controls: multi_grid_controls_cls = ...
    algebric_mg_controls: algebric_mg_controls_cls = ...
    fas_mg_controls: fas_mg_controls_cls = ...
    amg_gpgpu_options: amg_gpgpu_options_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .start_time import start_time as start_time_cls
from .stop_time import stop_time as stop_time_cls

class times(Group):
    """
    'times' child.
    """

    fluent_name = "times"

    child_names = \
        ['start_time', 'stop_time']

    _child_classes = dict(
        start_time=start_time_cls,
        stop_time=stop_time_cls,
    )

    return_type = "<object object at 0x7f5c26922220>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .volumetric_species import volumetric_species as volumetric_species_cls
from .last_species import last_species as last_species_cls

class species(Group):
    """
    'species' child.
    """

    fluent_name = "species"

    child_names = \
        ['volumetric_species', 'last_species']

    _child_classes = dict(
        volumetric_species=volumetric_species_cls,
        last_species=last_species_cls,
    )

    return_type = "<object object at 0x7fc3dc2bb9b0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .phase_22 import phase as phase_cls
from .name_2 import name as name_cls
from .geom_disable import geom_disable as geom_disable_cls
from .geom_dir_spec import geom_dir_spec as geom_dir_spec_cls
from .geom_dir_x import geom_dir_x as geom_dir_x_cls
from .geom_dir_y import geom_dir_y as geom_dir_y_cls
from .geom_dir_z import geom_dir_z as geom_dir_z_cls
from .geom_levels import geom_levels as geom_levels_cls
from .geom_bgthread import geom_bgthread as geom_bgthread_cls
from .flow_spec import flow_spec as flow_spec_cls
from .mass_flow import mass_flow as mass_flow_cls
from .mass_flux import mass_flux as mass_flux_cls
from .solar_fluxes import solar_fluxes as solar_fluxes_cls
from .solar_shining_factor import solar_shining_factor as solar_shining_factor_cls

class recirculation_outlet_child(Group):
    """
    'child_object_type' of recirculation_outlet.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['phase', 'name', 'geom_disable', 'geom_dir_spec', 'geom_dir_x',
         'geom_dir_y', 'geom_dir_z', 'geom_levels', 'geom_bgthread',
         'flow_spec', 'mass_flow', 'mass_flux', 'solar_fluxes',
         'solar_shining_factor']

    _child_classes = dict(
        phase=phase_cls,
        name=name_cls,
        geom_disable=geom_disable_cls,
        geom_dir_spec=geom_dir_spec_cls,
        geom_dir_x=geom_dir_x_cls,
        geom_dir_y=geom_dir_y_cls,
        geom_dir_z=geom_dir_z_cls,
        geom_levels=geom_levels_cls,
        geom_bgthread=geom_bgthread_cls,
        flow_spec=flow_spec_cls,
        mass_flow=mass_flow_cls,
        mass_flux=mass_flux_cls,
        solar_fluxes=solar_fluxes_cls,
        solar_shining_factor=solar_shining_factor_cls,
    )

    return_type = "<object object at 0x7fc3bc789cd0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)


class pairing_between_different_cell_zones_only(Boolean):
    """
    Pairing between interface zones from different cell zones only.
    """

    fluent_name = "pairing-between-different-cell-zones-only?"

    return_type = "<object object at 0x7fc3bc3a9bd0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .o2o_flag import o2o_flag as o2o_flag_cls
from .toggle import toggle as toggle_cls
from .delete_empty import delete_empty as delete_empty_cls

class enable_one_to_one_pairing(Command):
    fluent_name = ...
    argument_names = ...
    o2o_flag: o2o_flag_cls = ...
    toggle: toggle_cls = ...
    delete_empty: delete_empty_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .delete import delete as delete_cls
from .display import display as display_cls
from .read_2 import read as read_cls

class surface_mesh(Group):
    fluent_name = ...
    command_names = ...

    def delete(self, surface: str):
        """
        Delete surface mesh.
        
        Parameters
        ----------
            surface : str
                'surface' child.
        
        """

    def display(self, ):
        """
        Display surface meshes.
        """

    def read(self, filename: str, unit: str):
        """
        Read surface meshes.
        
        Parameters
        ----------
            filename : str
                'filename' child.
            unit : str
                'unit' child.
        
        """

    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .host_file import host_file as host_file_cls

class save_hosts(Command):
    """
    Write a hosts file.
    
    Parameters
    ----------
        host_file : str
            'host_file' child.
    
    """

    fluent_name = "save-hosts"

    argument_names = \
        ['host_file']

    _child_classes = dict(
        host_file=host_file_cls,
    )

    return_type = "<object object at 0x7fc3a7e886e0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .patch_reconstructed_interface import patch_reconstructed_interface as patch_reconstructed_interface_cls
from .use_volumetric_smoothing import use_volumetric_smoothing as use_volumetric_smoothing_cls
from .smoothing_relaxation_factor import smoothing_relaxation_factor as smoothing_relaxation_factor_cls
from .execute_smoothing import execute_smoothing as execute_smoothing_cls

class vof_smooth_options(Group):
    """
    Enter the vof patch/smooth options menu.
    """

    fluent_name = "vof-smooth-options"

    child_names = \
        ['patch_reconstructed_interface', 'use_volumetric_smoothing',
         'smoothing_relaxation_factor']

    command_names = \
        ['execute_smoothing']

    _child_classes = dict(
        patch_reconstructed_interface=patch_reconstructed_interface_cls,
        use_volumetric_smoothing=use_volumetric_smoothing_cls,
        smoothing_relaxation_factor=smoothing_relaxation_factor_cls,
        execute_smoothing=execute_smoothing_cls,
    )

    return_type = "<object object at 0x7fc3bc2a79d0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .implicit_bodyforce_treatment import implicit_bodyforce_treatment as implicit_bodyforce_treatment_cls
from .velocity_formulation import velocity_formulation as velocity_formulation_cls
from .physical_velocity_formulation import physical_velocity_formulation as physical_velocity_formulation_cls
from .disable_rhie_chow_flux import disable_rhie_chow_flux as disable_rhie_chow_flux_cls
from .presto_pressure_scheme import presto_pressure_scheme as presto_pressure_scheme_cls
from .first_to_second_order_blending import first_to_second_order_blending as first_to_second_order_blending_cls
from .alternate_diffusion_for_porous_region_solids import alternate_diffusion_for_porous_region_solids as alternate_diffusion_for_porous_region_solids_cls

class numerics_pbns(Group):
    fluent_name = ...
    child_names = ...
    implicit_bodyforce_treatment: implicit_bodyforce_treatment_cls = ...
    velocity_formulation: velocity_formulation_cls = ...
    physical_velocity_formulation: physical_velocity_formulation_cls = ...
    disable_rhie_chow_flux: disable_rhie_chow_flux_cls = ...
    presto_pressure_scheme: presto_pressure_scheme_cls = ...
    first_to_second_order_blending: first_to_second_order_blending_cls = ...
    alternate_diffusion_for_porous_region_solids: alternate_diffusion_for_porous_region_solids_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .width_1 import width as width_cls
from .height_1 import height as height_cls
from .margin_1 import margin as margin_cls

class pixel_size(Group):
    """
    'pixel_size' child.
    """

    fluent_name = "pixel-size"

    child_names = \
        ['width', 'height', 'margin']

    _child_classes = dict(
        width=width_cls,
        height=height_cls,
        margin=margin_cls,
    )

    return_type = "<object object at 0x7f5bb1256a10>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .multi_grid import multi_grid as multi_grid_cls
from .multi_stage import multi_stage as multi_stage_cls
from .expert_1 import expert as expert_cls
from .fast_transient_settings import fast_transient_settings as fast_transient_settings_cls
from .relaxation_method import relaxation_method as relaxation_method_cls
from .correction_tolerance import correction_tolerance as correction_tolerance_cls
from .anisotropic_solid_heat_transfer import anisotropic_solid_heat_transfer as anisotropic_solid_heat_transfer_cls

class advanced(Group):
    """
    'advanced' child.
    """

    fluent_name = "advanced"

    child_names = \
        ['multi_grid', 'multi_stage', 'expert', 'fast_transient_settings',
         'relaxation_method', 'correction_tolerance',
         'anisotropic_solid_heat_transfer']

    _child_classes = dict(
        multi_grid=multi_grid_cls,
        multi_stage=multi_stage_cls,
        expert=expert_cls,
        fast_transient_settings=fast_transient_settings_cls,
        relaxation_method=relaxation_method_cls,
        correction_tolerance=correction_tolerance_cls,
        anisotropic_solid_heat_transfer=anisotropic_solid_heat_transfer_cls,
    )

    return_type = "<object object at 0x7f5bb1467210>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .check_mapped_interface_quality import check_mapped_interface_quality as check_mapped_interface_quality_cls
from .complete import complete as complete_cls
from .tol_percentage_increment import tol_percentage_increment as tol_percentage_increment_cls

class improve_quality(Command):
    """
    Improve mesh interface quality.
    
    Parameters
    ----------
        check_mapped_interface_quality : bool
            Check Mapped Interface Qaulity.
        complete : bool
            Continue to improve the mapped interface quality.
        tol_percentage_increment : real
            'tol_percentage_increment' child.
    
    """

    fluent_name = "improve-quality"

    argument_names = \
        ['check_mapped_interface_quality', 'complete',
         'tol_percentage_increment']

    _child_classes = dict(
        check_mapped_interface_quality=check_mapped_interface_quality_cls,
        complete=complete_cls,
        tol_percentage_increment=tol_percentage_increment_cls,
    )

    return_type = "<object object at 0x7fc3bc3aa210>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .across_zones import across_zones as across_zones_cls
from .method_1 import method as method_cls
from .load_vector import load_vector as load_vector_cls
from .pre_test import pre_test as pre_test_cls
from .use_case_file_method import use_case_file_method as use_case_file_method_cls

class auto(Group):
    fluent_name = ...
    child_names = ...
    across_zones: across_zones_cls = ...
    method: method_cls = ...
    load_vector: load_vector_cls = ...
    pre_test: pre_test_cls = ...
    command_names = ...

    def use_case_file_method(self, file_partition_method: bool):
        """
        Enable the use-case-file method for auto partitioning.
        
        Parameters
        ----------
            file_partition_method : bool
                'file_partition_method' child.
        
        """

    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .min_point import min_point as min_point_cls
from .max_point import max_point as max_point_cls
from .inside import inside as inside_cls
from .create_volume_surface import create_volume_surface as create_volume_surface_cls

class hexahedron(Group):
    """
    'hexahedron' child.
    """

    fluent_name = "hexahedron"

    child_names = \
        ['min_point', 'max_point', 'inside', 'create_volume_surface']

    _child_classes = dict(
        min_point=min_point_cls,
        max_point=max_point_cls,
        inside=inside_cls,
        create_volume_surface=create_volume_surface_cls,
    )

    return_type = "<object object at 0x7f5bb13596c0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .axes_2 import axes as axes_cls
from .main import main as main_cls
from .scale_3 import scale as scale_cls
from .text import text as text_cls
from .video import video as video_cls
from .xy import xy as xy_cls
from .logo import logo as logo_cls
from .ruler_1 import ruler as ruler_cls
from .logo_color import logo_color as logo_color_cls
from .aspect_ratio import aspect_ratio as aspect_ratio_cls

class windows(Group):
    fluent_name = ...
    child_names = ...
    axes: axes_cls = ...
    main: main_cls = ...
    scale: scale_cls = ...
    text: text_cls = ...
    video: video_cls = ...
    xy: xy_cls = ...
    logo: logo_cls = ...
    ruler: ruler_cls = ...
    logo_color: logo_color_cls = ...
    command_names = ...

    def aspect_ratio(self, width: Union[float, str], height: Union[float, str]):
        """
        Set the aspect ratio of the active window.
        
        Parameters
        ----------
            width : real
                'width' child.
            height : real
                'height' child.
        
        """

    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .domain import domain as domain_cls
from .cell_zones import cell_zones as cell_zones_cls
from .register_id import register_id as register_id_cls
from .variable import variable as variable_cls
from .patch_velocity import patch_velocity as patch_velocity_cls
from .use_custom_field_function import use_custom_field_function as use_custom_field_function_cls
from .custom_field_function_name import custom_field_function_name as custom_field_function_name_cls
from .value_1 import value as value_cls

class calculate_patch(Command):
    """
    Patch a value for a flow variable in the domain.
    
    Parameters
    ----------
        domain : str
            'domain' child.
        cell_zones : List
            'cell_zones' child.
        register_id : List
            'register_id' child.
        variable : str
            'variable' child.
        patch_velocity : bool
            'patch_velocity' child.
        use_custom_field_function : bool
            'use_custom_field_function' child.
        custom_field_function_name : str
            'custom_field_function_name' child.
        value : real
            'value' child.
    
    """

    fluent_name = "calculate-patch"

    argument_names = \
        ['domain', 'cell_zones', 'register_id', 'variable', 'patch_velocity',
         'use_custom_field_function', 'custom_field_function_name', 'value']

    _child_classes = dict(
        domain=domain_cls,
        cell_zones=cell_zones_cls,
        register_id=register_id_cls,
        variable=variable_cls,
        patch_velocity=patch_velocity_cls,
        use_custom_field_function=use_custom_field_function_cls,
        custom_field_function_name=custom_field_function_name_cls,
        value=value_cls,
    )

    return_type = "<object object at 0x7fc3bc2a7a80>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .enable_pseudo_time_method import enable_pseudo_time_method as enable_pseudo_time_method_cls
from .pseudo_time_scale_factor import pseudo_time_scale_factor as pseudo_time_scale_factor_cls
from .implicit_under_relaxation_factor import implicit_under_relaxation_factor as implicit_under_relaxation_factor_cls

class local_dt_child(Group):
    fluent_name = ...
    child_names = ...
    enable_pseudo_time_method: enable_pseudo_time_method_cls = ...
    pseudo_time_scale_factor: pseudo_time_scale_factor_cls = ...
    implicit_under_relaxation_factor: implicit_under_relaxation_factor_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)


class vof_to_min_limit(Real):
    """
    Minimum volume fraction below which mass transfer rate is set to zero.
    """

    fluent_name = "vof-to-min-limit"

    return_type = "<object object at 0x7f5bb1467ca0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .diameter import diameter as diameter_cls
from .diameter_2 import diameter_2 as diameter_2_cls
from .option import option as option_cls
from .rosin_rammler_settings import rosin_rammler_settings as rosin_rammler_settings_cls
from .tabulated_size_settings import tabulated_size_settings as tabulated_size_settings_cls

class particle_size(Group):
    fluent_name = ...
    child_names = ...
    diameter: diameter_cls = ...
    diameter_2: diameter_2_cls = ...
    option: option_cls = ...
    rosin_rammler_settings: rosin_rammler_settings_cls = ...
    tabulated_size_settings: tabulated_size_settings_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .enable_gpu import enable_gpu as enable_gpu_cls
from .term_criterion import term_criterion as term_criterion_cls
from .solver_1 import solver as solver_cls
from .max_num_cycle import max_num_cycle as max_num_cycle_cls
from .coarsen_by_size import coarsen_by_size as coarsen_by_size_cls
from .pre_sweep import pre_sweep as pre_sweep_cls
from .post_sweep import post_sweep as post_sweep_cls
from .smoother import smoother as smoother_cls

class amg_gpgpu_options_child(Group):
    fluent_name = ...
    child_names = ...
    enable_gpu: enable_gpu_cls = ...
    term_criterion: term_criterion_cls = ...
    solver: solver_cls = ...
    max_num_cycle: max_num_cycle_cls = ...
    coarsen_by_size: coarsen_by_size_cls = ...
    pre_sweep: pre_sweep_cls = ...
    post_sweep: post_sweep_cls = ...
    smoother: smoother_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .symbol import symbol as symbol_cls
from .size_1 import size as size_cls
from .color import color as color_cls

class markers_child(Group):
    """
    'child_object_type' of markers.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['symbol', 'size', 'color']

    _child_classes = dict(
        symbol=symbol_cls,
        size=size_cls,
        color=color_cls,
    )

    return_type = "<object object at 0x7fc3bc192c10>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .option import option as option_cls
from .shape_factor import shape_factor as shape_factor_cls
from .cunningham_factor import cunningham_factor as cunningham_factor_cls

class particle_drag(Group):
    """
    'particle_drag' child.
    """

    fluent_name = "particle-drag"

    child_names = \
        ['option', 'shape_factor', 'cunningham_factor']

    _child_classes = dict(
        option=option_cls,
        shape_factor=shape_factor_cls,
        cunningham_factor=cunningham_factor_cls,
    )

    return_type = "<object object at 0x7fc41c4f47b0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .case_frequency import case_frequency as case_frequency_cls
from .data_frequency import data_frequency as data_frequency_cls
from .root_name import root_name as root_name_cls
from .retain_most_recent_files import retain_most_recent_files as retain_most_recent_files_cls
from .max_files import max_files as max_files_cls
from .append_file_name_with import append_file_name_with as append_file_name_with_cls
from .save_data_file_every import save_data_file_every as save_data_file_every_cls

class auto_save(Group):
    fluent_name = ...
    child_names = ...
    case_frequency: case_frequency_cls = ...
    data_frequency: data_frequency_cls = ...
    root_name: root_name_cls = ...
    retain_most_recent_files: retain_most_recent_files_cls = ...
    max_files: max_files_cls = ...
    append_file_name_with: append_file_name_with_cls = ...
    save_data_file_every: save_data_file_every_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .ni import ni as ni_cls
from .nj import nj as nj_cls
from .nk import nk as nk_cls
from .xe import xe as xe_cls
from .len import len as len_cls

class beach_dir_list_child(Group):
    fluent_name = ...
    child_names = ...
    ni: ni_cls = ...
    nj: nj_cls = ...
    nk: nk_cls = ...
    xe: xe_cls = ...
    len: len_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .x_axis_2 import x_axis as x_axis_cls
from .x_axis_min import x_axis_min as x_axis_min_cls
from .x_axis_max import x_axis_max as x_axis_max_cls
from .y_axis_2 import y_axis as y_axis_cls
from .y_axis_min import y_axis_min as y_axis_min_cls
from .y_axis_max import y_axis_max as y_axis_max_cls

class auto_scale(Group):
    fluent_name = ...
    child_names = ...
    x_axis: x_axis_cls = ...
    x_axis_min: x_axis_min_cls = ...
    x_axis_max: x_axis_max_cls = ...
    y_axis: y_axis_cls = ...
    y_axis_min: y_axis_min_cls = ...
    y_axis_max: y_axis_max_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .viscous_heating import viscous_heating as viscous_heating_cls
from .low_pressure_slip import low_pressure_slip as low_pressure_slip_cls
from .curvature_correction import curvature_correction as curvature_correction_cls
from .corner_flow_correction import corner_flow_correction as corner_flow_correction_cls
from .production_kato_launder import production_kato_launder as production_kato_launder_cls
from .production_limiter import production_limiter as production_limiter_cls

class options(Group):
    """
    'options' child.
    """

    fluent_name = "options"

    child_names = \
        ['viscous_heating', 'low_pressure_slip', 'curvature_correction',
         'corner_flow_correction', 'production_kato_launder',
         'production_limiter']

    _child_classes = dict(
        viscous_heating=viscous_heating_cls,
        low_pressure_slip=low_pressure_slip_cls,
        curvature_correction=curvature_correction_cls,
        corner_flow_correction=corner_flow_correction_cls,
        production_kato_launder=production_kato_launder_cls,
        production_limiter=production_limiter_cls,
    )

    return_type = "<object object at 0x7ff789525100>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .option_3 import option as option_cls
from .consistency_index import consistency_index as consistency_index_cls
from .power_law_index import power_law_index as power_law_index_cls
from .minimum_viscosity import minimum_viscosity as minimum_viscosity_cls
from .maximum_viscosity import maximum_viscosity as maximum_viscosity_cls
from .reference_temperature import reference_temperature as reference_temperature_cls
from .activation_energy import activation_energy as activation_energy_cls

class non_newtonian_power_law(Group):
    """
    'non_newtonian_power_law' child.
    """

    fluent_name = "non-newtonian-power-law"

    child_names = \
        ['option', 'consistency_index', 'power_law_index',
         'minimum_viscosity', 'maximum_viscosity', 'reference_temperature',
         'activation_energy']

    _child_classes = dict(
        option=option_cls,
        consistency_index=consistency_index_cls,
        power_law_index=power_law_index_cls,
        minimum_viscosity=minimum_viscosity_cls,
        maximum_viscosity=maximum_viscosity_cls,
        reference_temperature=reference_temperature_cls,
        activation_energy=activation_energy_cls,
    )

    return_type = "<object object at 0x7f5bb1c18860>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .particle_drag import particle_drag as particle_drag_cls
from .particle_rotation import particle_rotation as particle_rotation_cls
from .heat_exchange import heat_exchange as heat_exchange_cls
from .custom_laws import custom_laws as custom_laws_cls
from .turbulent_dispersion import turbulent_dispersion as turbulent_dispersion_cls
from .droplet_breakup import droplet_breakup as droplet_breakup_cls

class physical_models(Group):
    fluent_name = ...
    child_names = ...
    particle_drag: particle_drag_cls = ...
    particle_rotation: particle_rotation_cls = ...
    heat_exchange: heat_exchange_cls = ...
    custom_laws: custom_laws_cls = ...
    turbulent_dispersion: turbulent_dispersion_cls = ...
    droplet_breakup: droplet_breakup_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .averaging import averaging as averaging_cls
from .source_terms import source_terms as source_terms_cls
from .tracking import tracking as tracking_cls

class numerics(Group):
    """
    Main menu to allow users to set options controlling the solution of ordinary differential equations describing 
    the underlying physics of the Discrete Phase Model.
    For more details consult the help option of the corresponding menu or TUI command.
    """

    fluent_name = "numerics"

    child_names = \
        ['averaging', 'source_terms', 'tracking']

    _child_classes = dict(
        averaging=averaging_cls,
        source_terms=source_terms_cls,
        tracking=tracking_cls,
    )

    return_type = "<object object at 0x7fc41c4f53e0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .name_1 import name as name_cls
from .python_name_1 import python_name_1 as python_name_1_cls
from .type_7 import type as type_cls
from .display_options import display_options as display_options_cls

class cell_registers_child(Group):
    fluent_name = ...
    child_names = ...
    name: name_cls = ...
    python_name_1: python_name_1_cls = ...
    type: type_cls = ...
    display_options: display_options_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .enable_1 import enable as enable_cls
from .disable import disable as disable_cls
from .print import print as print_cls
from .clear import clear as clear_cls

class profile(Group):
    """
    Enter the adaption profile menu.
    """

    fluent_name = "profile"

    command_names = \
        ['enable', 'disable', 'print', 'clear']

    _child_classes = dict(
        enable=enable_cls,
        disable=disable_cls,
        print=print_cls,
        clear=clear_cls,
    )

    return_type = "<object object at 0x7fc42e67b110>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .right import right as right_cls
from .up import up as up_cls

class pan(Command):
    """
    Adjust the camera position without modifying the position.
    
    Parameters
    ----------
        right : real
            'right' child.
        up : real
            'up' child.
    
    """

    fluent_name = "pan"

    argument_names = \
        ['right', 'up']

    _child_classes = dict(
        right=right_cls,
        up=up_cls,
    )

    return_type = "<object object at 0x7ff703070ea0>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .high_order_rc import high_order_rc as high_order_rc_cls
from .high_order_rc_hybrid_treatment import high_order_rc_hybrid_treatment as high_order_rc_hybrid_treatment_cls
from .force_treatment_of_unsteady_rc import force_treatment_of_unsteady_rc as force_treatment_of_unsteady_rc_cls
from .unstructured_var_presto_scheme import unstructured_var_presto_scheme as unstructured_var_presto_scheme_cls
from .new_framework_for_vof_specific_node_based_treatment import new_framework_for_vof_specific_node_based_treatment as new_framework_for_vof_specific_node_based_treatment_cls

class vof_numerics(Group):
    fluent_name = ...
    child_names = ...
    high_order_rc: high_order_rc_cls = ...
    high_order_rc_hybrid_treatment: high_order_rc_hybrid_treatment_cls = ...
    force_treatment_of_unsteady_rc: force_treatment_of_unsteady_rc_cls = ...
    unstructured_var_presto_scheme: unstructured_var_presto_scheme_cls = ...
    new_framework_for_vof_specific_node_based_treatment: new_framework_for_vof_specific_node_based_treatment_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .mesh_1 import mesh as mesh_cls
from .contour import contour as contour_cls
from .vector import vector as vector_cls
from .pathlines import pathlines as pathlines_cls
from .particle_tracks import particle_tracks as particle_tracks_cls
from .lic import lic as lic_cls
from .views import views as views_cls

class graphics(Group):
    fluent_name = ...
    child_names = ...
    mesh: mesh_cls = ...
    contour: contour_cls = ...
    vector: vector_cls = ...
    pathlines: pathlines_cls = ...
    particle_tracks: particle_tracks_cls = ...
    lic: lic_cls = ...
    views: views_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .blended_compressive_scheme import blended_compressive_scheme as blended_compressive_scheme_cls
from .pseudo_transient_stabilization import pseudo_transient_stabilization as pseudo_transient_stabilization_cls

class additional_stabilization_controls(Group):
    """
    'additional_stabilization_controls' child.
    """

    fluent_name = "additional-stabilization-controls"

    child_names = \
        ['blended_compressive_scheme', 'pseudo_transient_stabilization']

    _child_classes = dict(
        blended_compressive_scheme=blended_compressive_scheme_cls,
        pseudo_transient_stabilization=pseudo_transient_stabilization_cls,
    )

    return_type = "<object object at 0x7ff703161800>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .border_2 import border as border_cls
from .bottom_2 import bottom as bottom_cls
from .clear_2 import clear as clear_cls
from .format_1 import format as format_cls
from .font_size_1 import font_size as font_size_cls
from .left_2 import left as left_cls
from .margin import margin as margin_cls
from .right_3 import right as right_cls
from .top_2 import top as top_cls
from .visible_3 import visible as visible_cls

class scale(Group):
    fluent_name = ...
    child_names = ...
    border: border_cls = ...
    bottom: bottom_cls = ...
    clear: clear_cls = ...
    format: format_cls = ...
    font_size: font_size_cls = ...
    left: left_cls = ...
    margin: margin_cls = ...
    right: right_cls = ...
    top: top_cls = ...
    visible: visible_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .zone_name_2 import zone_name as zone_name_cls

class get_non_overlapping_zone_name(Query):
    """
    Get non-overlapping zone name from the associated interface zone.
    
    Parameters
    ----------
        zone_name : str
            Enter zone name.
    
    """

    fluent_name = "get-non-overlapping-zone-name"

    argument_names = \
        ['zone_name']

    _child_classes = dict(
        zone_name=zone_name_cls,
    )

    return_type = "<object object at 0x7fc3bc3aa370>"



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .number_of_partitions import number_of_partitions as number_of_partitions_cls

class combine_partition(Command):
    """
    Merge every N partitions.
    
    Parameters
    ----------
        number_of_partitions : int
            'number_of_partitions' child.
    
    """

    fluent_name = "combine-partition"

    argument_names = \
        ['number_of_partitions']

    _child_classes = dict(
        number_of_partitions=number_of_partitions_cls,
    )

    return_type = "<object object at 0x7fc3a7e88190>"



#
# This is an auto-generated file.  DO NOT EDIT!
#


from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from typing import Union, List, Tuple

from .solar_frequency_data import solar_frequency_data as solar_frequency_data_cls
from .solar_filename import solar_filename as solar_filename_cls
from .use_binary_format import use_binary_format as use_binary_format_cls

class autosave_solar_data(Group):
    fluent_name = ...
    child_names = ...
    solar_frequency_data: solar_frequency_data_cls = ...
    solar_filename: solar_filename_cls = ...
    use_binary_format: use_binary_format_cls = ...
    return_type = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import (
    _ChildNamedObjectAccessorMixin,
    CreatableNamedObjectMixin,
    _NonCreatableNamedObjectMixin,
    AllowedValuesMixin,
    _InputFile,
    _OutputFile,
    _InOutFile,
)

from .limiter_type import limiter_type as limiter_type_cls
from .cell_to_limiting import cell_to_limiting as cell_to_limiting_cls
from .limiter_filter import limiter_filter as limiter_filter_cls

class spatial_discretization_limiter(Group):
    """
    Enter the slope limiter set menu.
    """

    fluent_name = "spatial-discretization-limiter"

    child_names = \
        ['limiter_type', 'cell_to_limiting', 'limiter_filter']

    _child_classes = dict(
        limiter_type=limiter_type_cls,
        cell_to_limiting=cell_to_limiting_cls,
        limiter_filter=limiter_filter_cls,
    )

    return_type = "<object object at 0x7fc3bc2a4c80>"
